0x3st fully agreed that security is of significant importance for users. Thus 0x3st promise all the codes in this reporistry excludes any kinds of malware, at least intentionally.

0x3st also call for contributors to detect or fix the security issues. You are encouraged to report vulnerable issues privately through email or `Private vulnerability reporting`.